@@ -25,7 +25,7 @@ from typing import (
     TYPE_CHECKING,
 )
 
-from pytket.backends import CircuitNotRunError, ResultHandle
+from pytket.backends import Backend, CircuitNotRunError, ResultHandle
 from pytket.backends.backendinfo import BackendInfo
 from pytket.backends.backendresult import BackendResult
 from pytket.backends.resulthandle import _ResultIdTuple
@@ -113,7 +113,7 @@ class IBMQEmulatorBackend(AerBackend):
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
@@ -122,13 +122,11 @@ class IBMQEmulatorBackend(AerBackend):
         Supported kwargs: `seed`, `postprocess`.
         """
         circuits = list(circuits)
-        if hasattr(n_shots, "__iter__"):
-            n_shots_list = list(cast(Sequence[Optional[int]], n_shots))
-            if len(n_shots_list) != len(circuits):
-                raise ValueError("The length of n_shots and circuits must match")
-        else:
-            # convert n_shots to a list
-            n_shots_list = [cast(Optional[int], n_shots)] * len(circuits)
+        n_shots_list = Backend._get_n_shots_as_list(
+            n_shots,
+            len(circuits),
+            optional=True,
+        )
 
         if valid_check:
             self._check_all_circuits(circuits)
